@@ -18,6 +18,15 @@ SAFE_HTTP_METHODS = ['GET', 'HEAD', 'OPTIONS']
 class OAuthLibMixin(object):
     """
     This mixin decouples Django OAuth Toolkit from OAuthLib.
+
+    Users can configure the Server, Validator and OAuthlibCore
+    classes used by this mixin by setting the following class
+    variables:
+
+      * server_class
+      * validator_class
+      * oauthlib_core_class  # TODO rename it as oauthlib_backend_class
+
     """
     server_class = None
     validator_class = None
@@ -46,6 +55,18 @@ class OAuthLibMixin(object):
         else:
             return cls.validator_class
 
+    @classmethod
+    def get_oauthlib_core_class(cls):
+        """
+        Return the OAuthLibCore implementation class to use, silently
+        defaults to OAuthLibCore class from oauth2_provider package
+
+        # TODO rename this as get_oauthlib_backend_class
+        """
+        if not hasattr(cls, 'oauthlib_core_class'):
+            return OAuthLibCore
+        return cls.oauthlib_core_class
+
     @classmethod
     def get_server(cls):
         """
@@ -63,7 +84,8 @@ class OAuthLibMixin(object):
         """
         if not hasattr(cls, '_oauthlib_core'):
             server = cls.get_server()
-            cls._oauthlib_core = OAuthLibCore(server)
+            core_class = cls.get_oauthlib_core_class()
+            cls._oauthlib_core = core_class(server)
         return cls._oauthlib_core
 
     def validate_authorization_request(self, request):
